/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Record.java,v 1.6 2004/02/08 02:49:44 vgritsenko Exp $
 */

package org.apache.xindice.core.data;

import java.util.Map;

/**
 * Record is a container for Key/Value pair.  Record also provides
 * metadata for a Value stored in the database.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 02:49:44 $
 */
public final class Record {
    public static final String CREATED = "created";
    public static final String MODIFIED = "modified";
    public static final String OWNER = "owner";
    public static final String GROUP = "group";

    private Key key = null;
    private Value value = null;
    private Map meta = null;

    public Record() {
    }

    public Record(Key key, Value value, Map meta) {
        this.key = key;
        this.value = value;
        this.meta = meta;
    }

    public Record(Key key, Value value) {
        this.key = key;
        this.value = value;
    }

    /**
     * getKey returns the Record's Key.
     *
     * @return The Record's Key
     */
    public Key getKey() {
        return key;
    }

    /**
     * setValue sets the Record's Value.
     *
     * @param value The new Value
     */
    public void setValue(Value value) {
        this.value = value;
    }

    /**
     * setValue sets the Record's Value.
     *
     * @param value The new Value
     */
    public void setValue(String value) {
        this.value = new Value(value);
    }

    /**
     * getValue returns the Record's Value.
     *
     * @return The Record's Value
     */
    public Value getValue() {
        return value;
    }

    /**
     * getMetaData returns metadata about the Value.
     *
     * @param name The property name
     * @return The metadata value
     */
    public Object getMetaData(Object name) {
        return meta != null ? meta.get(name) : null;
    }
}
