/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: InlineMetaReader.java,v 1.4 2004/02/08 02:50:37 vgritsenko Exp $
 */

package org.apache.xindice.core.meta.inline;

/**
 * The <code>Value</code> associated with a <code>Record</code>
 * can be prefixed by a header containing 'inline' metadata.
 * The original motivation for
 * this extension is to support binary resources in the same
 * filer where the XML documents live.
 *
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 02:50:37 $
 */
public interface InlineMetaReader {

    /**
     * The second byte of the header contains the version.
     * The reader which is called to read the header is
     * determined by the version.
     */
    int getVersion();

    /**
     * When a header is read, it generates a <code>Map</code>
     * containing the attributes carried by the header.
     *
     * @param data array in which the header is embedded
     * @param offset from the beginning of the data array to the
     *        beginning of the header.
     * @param length of the header data
     * @return Map containing the attributes read from the header
     * @throws InlineMetaException if the header data is corrupted or of
     *         the wrong length
     */
    InlineMetaMap read(byte[] data, int offset, int length) throws InlineMetaException;
}
