/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: InlineMetaWriter.java,v 1.4 2004/02/08 02:50:37 vgritsenko Exp $
 */

package org.apache.xindice.core.meta.inline;

/**
 * The <code>Value</code> associated with a <code>Record</code>
 * can be prefixed by a header containing 'inline' metadata.
 * This class writes the metadata carried by the header.
 * The original motivation for
 * this extension is to support binary resources in the same
 * filer where the XML documents live.
 *
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 02:50:37 $
 */
public interface InlineMetaWriter {

    /**
     * The header version created by the implementing writer.
     */
    int getVersion();

    /**
     * Create the metadata.  The contents are drawn from the map.
     *
     * @param map from which the metadata is drawn
     * @throws InlineMetaException if the map is not usable by this
     *         writer, or is missing required entries.
     */
    byte[] getMetadata(InlineMetaMap map) throws InlineMetaException;
}
