/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Query.java,v 1.11 2004/02/24 03:20:27 vgritsenko Exp $
 */

package org.apache.xindice.server.rpc.messages;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.NodeSet;
import org.apache.xindice.core.query.QueryUtil;
import org.apache.xindice.server.rpc.RPCDefaultMessage;
import org.apache.xindice.xml.NamespaceMap;

import java.util.Enumeration;
import java.util.Hashtable;

/**
 * Executes a query against a document or collection
 *
 * @version CVS $Revision: 1.11 $, $Date: 2004/02/24 03:20:27 $
 */
public class Query extends RPCDefaultMessage {

    public Hashtable execute(Hashtable message) throws Exception {

        if (!message.containsKey(COLLECTION)) {
            throw new Exception(MISSING_COLLECTION_PARAM);
        }

        final String type = (String) message.get(TYPE);
        if (type == null) {
            throw new Exception(MISSING_TYPE_PARAM);
        }

        final String query = (String) message.get(QUERY);
        if (query == null) {
            throw new Exception(MISSING_QUERY_PARAM);
        }

        Collection col = getCollection((String) message.get(COLLECTION));
        NamespaceMap nsMap = QueryUtil.mapNamespaces((Hashtable) message.get(NAMESPACES));

        NodeSet ns;
        if (message.containsKey(NAME)) {
            ns = col.queryDocument(type, query, nsMap, message.get(NAME));
        } else {
            ns = col.queryCollection(type, query, nsMap);
        }

        Hashtable result = new Hashtable();
        result.put(RESULT, QueryUtil.queryResultsToString(ns));
        return result;
    }
}
