/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: AddMultipleDocuments.java,v 1.10 2004/02/08 02:57:35 vgritsenko Exp $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.io.File;
import java.io.FileInputStream;
import java.io.FilenameFilter;
import java.util.Hashtable;

/**
 * AddMultipleDocuments.java is designed to let the user add several Documents
 * to an existing Collection at one time.
 *
 * Documents are added with an ID the same as the file name.
 * This command assumes that the collection being added to already exists!
 *
 * @version CVS $Revision: 1.10 $, $Date: 2004/02/08 02:57:35 $
 */
public class AddMultipleDocuments extends Command {

    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        try {

            // Verify that user has supplied necessary arguments
            if (table.get(XMLTools.COLLECTION) == null) {
                System.out.println("ERROR : Collection and switch required");
                return false;
            }

            if (table.get(XMLTools.FILE_PATH) == "") {
                System.out.println("ERROR : Directory name and switch required");
                return false;
            }

            // Get a Collection reference to the collection
            String colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                      (String) table.get(XMLTools.LOCAL));
            col = DatabaseManager.getCollection(colstring);
            if (col == null) {
                System.out.println("ERROR : Collection not found!");
                return false;
            }

            // Create a collection manager instance for the collection
            // CollectionManager colman = (CollectionManager)col.getService("CollectionManager",XMLDBAPIVERSION);

            // Get a File object for the Directory passed in
            File dir = new File((String) table.get(XMLTools.FILE_PATH));

            if (dir.isDirectory()) {

                String[] children = new String[]{};
                final String ext = (String) table.get(XMLTools.EXTENSION);

                // If the user supplied a file extension, filter on it, else use entire contents of the directory
                if (!ext.equals("")) {

                    children = dir.list(new FilenameFilter() {
                        public boolean accept(File none, String name) {
                            return name.endsWith("." + ext);
                        }
                    });
                } else if (ext.equals("")) {
                    children = dir.list();
                }

                System.out.println("Reading files from: " + dir.getName());

                // Loop over documents, adding to db
                for (int i = 0; i < children.length; i++) {

                    File files = new File(dir, children[i]);

                    if (files.isFile()) {
                        FileInputStream insr = new FileInputStream(files);
                        byte[] fileBuffer = new byte[(int) files.length()];
                        insr.read(fileBuffer);

                        try {

                            // Use the functionality already provided in Command.AddDocument to add this document
                            Command cmd = (Command) Class.forName("org.apache.xindice.tools.command.AddDocument").newInstance();
                            Hashtable localtable = new Hashtable();
                            String filepath = dir.getPath() + "/" + files.getName();

                            // Populate hashtable to pass to AddDocument class
                            localtable.put(XMLTools.COLLECTION, table.get(XMLTools.COLLECTION));
                            localtable.put(XMLTools.NAME_OF, files.getName());
                            localtable.put(XMLTools.FILE_PATH, filepath);

                            // Execute the class!
                            cmd.execute(localtable);

                        } catch (Exception e) {
                            System.out.println("Error Adding File: " + files.getName());
                            //System.out.println(e);
                            continue;
                        }
                    } else
                        continue;
                } // for loop
            }

        } finally {
            // Release all resources
            if (col != null) {
                col.close();
            }
        }

        return true;
    }

}

