/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: AddResource.java,v 1.2 2004/02/08 02:57:35 vgritsenko Exp $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;
import org.xmldb.api.base.Resource;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Hashtable;

/**
 * AddResource is designed to let the user add single binary resource
 * and/or multiple binary resources to any existing collection
 * within the current database.
 *
 * @version CVS $Revision: 1.2 $, $Date: 2004/02/08 02:57:35 $
 */
public class AddResource extends Command {

    /**
     * Adds a resource to the collection
     */
    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        if (table.get(XMLTools.COLLECTION) == null) {
            System.out.println("ERROR : Collection and switch required");
            return false;
        }

        if (table.get(XMLTools.FILE_PATH) == "") {
            System.out.println("ERROR : File path required");
            return false;
        }

        try {
            // Create a collection instance
            String colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                      (String) table.get(XMLTools.LOCAL));
            col = DatabaseManager.getCollection(colstring);
            if (col == null) {
                System.out.println("ERROR : Collection not found!");
                return false;
            }

            // Read data
            File file = new File((String) table.get(XMLTools.FILE_PATH));
            InputStream fis = new FileInputStream(file);
            byte[] data = new byte[fis.available()];
            fis.read(data);
            fis.close();

            // Create the BinaryResource and store the resource
            Resource resource = col.createResource((String) table.get(XMLTools.NAME_OF),
                                                   "BinaryResource");
            resource.setContent(data);
            col.storeResource(resource);

            System.out.println("Added resource " + table.get(XMLTools.COLLECTION) + "/" +
                               resource.getId());
            resource = null;
        } finally {
            if (col != null) {
                col.close();
            }
            col = null;
        }

        return true;
    }
}
