/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: ListCollectionDocuments.java,v 1.8 2004/02/08 02:57:35 vgritsenko Exp $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.util.Hashtable;

/**
 * ListCollectionDocumets.java is designed to let the user list all documents in a specific collection.
 *
 * NOTE:  Document names are returned in no specific order
 *
 * @version CVS $Revision: 1.8 $, $Date: 2004/02/08 02:57:35 $
 */
public class ListCollectionDocuments extends Command {

    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        String colstring = null;
        String[] documentarray = null;
        try {

            if (table.get(XMLTools.COLLECTION) != null) {

                // Create a collection instance
                colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                   (String) table.get(XMLTools.LOCAL));

                col = DatabaseManager.getCollection(colstring);
                if (col == null) {
                    System.out.println("ERROR : Collection not found!");
                    return false;
                }
                documentarray = col.listResources();

                System.out.println();

                for (int i = 0; i < documentarray.length; i++) {
                    System.out.println("\t" + documentarray[i]);
                }

                System.out.println("\nTotal documents: " + documentarray.length);
            } else
                System.out.println("ERROR : Collection and switch required");

        } finally {
            // Release the collection object
            if (col != null) {
                col.close();
            }
        }

        return true;
    }
}
