/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Configurable.java,v 1.5 2004/02/08 02:59:39 vgritsenko Exp $
 */

package org.apache.xindice.util;

/**
 * Configurable is a simple interface used to pass configuration information
 * to an object.  The implementing object is ultimately responsible for
 * maintaining any of that configuration information in any fashion it so
 * desires.  Most will create a Configuration instance to manage the data
 * in a consistent, and easy to access fashion.
 * <br><br>
 * A Configurable object should be considered 'configured' after receiving
 * a call to setConfig().  No additional configuration activities should be
 * expected of the instance, and so setConfig() should be the last call in
 * any set of configuration commands against an object.
 *
 * @see org.apache.xindice.util.Configuration
 * @version CVS $Revision: 1.5 $, $Date: 2004/02/08 02:59:39 $
 */
public interface Configurable {

    /**
     * setConfig sets the configuration information for the Configurable
     * object instance.
     *
     * @param config The configuration Node
     */
    void setConfig(Configuration config) throws XindiceException;

    /**
     * getConfig retrieves the configuration information for the
     * Configurable object instance.
     *
     * @return The configuration Node
     */
    Configuration getConfig();
}
