/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: ObjectQueue.java,v 1.6 2004/02/08 02:59:39 vgritsenko Exp $
 */

package org.apache.xindice.util;

import java.io.Serializable;

/**
 * ObjectQueue is a simple linked list implemention that can be used
 * for FIFO queuing.  The benefit of ObjectQueue over Sun's Queue
 * implementation is that it is not an extension of ArrayList and doesn't
 * suffer from ArrayList's resizing performance limitations.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 02:59:39 $
 */
public final class ObjectQueue implements Serializable {
    static final long serialVersionUID = 2573729619402197579L;

    private ObjectQueueItem first = null;
    private ObjectQueueItem last = null;
    private int size = 0;

    public synchronized void add(Object value) {
        size++;
        ObjectQueueItem q = new ObjectQueueItem(value);
        if (last != null) {
            last.next = q;
        }
        last = q;
        if (first == null) {
            first = q;
        }
    }

    public synchronized Object remove() {
        ObjectQueueItem q = first;
        if (q != null) {
            size--;
            first = q.next;
            if (first == null) {
                last = null;
            }
            return q.value;
        } else {
            return null;
        }
    }

    public boolean isEmpty() {
        return (size == 0);
    }

    public int size() {
        return size;
    }

    public synchronized Object peek() {
        return first != null ? first.value
                : null;
    }

    public synchronized void clear() {
        size = 0;
        first = null;
        last = null;
    }

    /**
     * ObjectQueueItem
     */

    private class ObjectQueueItem implements Serializable {
        public Object value;
        public ObjectQueueItem next;

        public ObjectQueueItem(Object value) {
            this.value = value;
        }
    }
}

