/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: ObjectStack.java,v 1.5 2004/02/08 02:59:39 vgritsenko Exp $
 */

package org.apache.xindice.util;

import java.io.Serializable;

/**
 * ObjectQueue is a simple linked list implemention that can be used
 * for LIFO stacking
 *
 * @version CVS $Revision: 1.5 $, $Date: 2004/02/08 02:59:39 $
 */
public final class ObjectStack implements Serializable {
    static final long serialVersionUID = -7896992305408562521L;

    private ObjectStackItem last = null;
    private int size = 0;

    public synchronized void push(Object value) {
        size++;
        ObjectStackItem q = new ObjectStackItem(value, last);
        last = q;
    }

    public synchronized Object pop() {
        ObjectStackItem q = last;
        if (q != null) {
            size--;
            last = q.prev;
            return q.value;
        }
        return null;
    }

    public boolean isEmpty() {
        return (size == 0);
    }

    public int size() {
        return size;
    }

    public synchronized Object peek() {
        return last != null ? last.value
                : null;
    }

    public synchronized void clear() {
        size = 0;
        last = null;
    }

    /**
     * ObjectStackItem
     */

    private class ObjectStackItem implements Serializable {
        public Object value;
        public ObjectStackItem prev;

        public ObjectStackItem(Object value, ObjectStackItem prev) {
            this.value = value;
            this.prev = prev;
        }
    }
}
