/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: DBNode.java,v 1.5 2004/02/08 03:11:56 vgritsenko Exp $
 */

package org.apache.xindice.xml.dom;

import org.apache.xindice.xml.NodeSource;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;

/**
 * DBNode represents a Xindice Collection-originating Node.  DBNodes will
 * provide Node sourcing and Transaction capabilities for Nodes that have
 * been aggregated into external Documents.
 *
 * @version CVS $Revision: 1.5 $, $Date: 2004/02/08 03:11:56 $
 */
public interface DBNode extends Node {
    /**
     * getSource returns a source for this Node.
     *
     * @return The Document source
     */
    NodeSource getSource();

    /**
     * setSource sets a source for this Node.
     *
     * @param source The Document source
     * @throws DOMException if an exception occurs
     */
    void setSource(NodeSource source) throws DOMException;

    /**
     * expandSource expands the source into the Node as
     * a namespace and a set of attributes.  This method
     * will only work on a Document or an Element, and
     * should silently fail on all other Node types.
     */
    void expandSource();
}
