/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: EntityImpl.java,v 1.4 2004/02/08 03:11:56 vgritsenko Exp $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.Entity;
import org.w3c.dom.Node;

/**
 * EntityImpl
 *
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 03:11:56 $
 */
public final class EntityImpl extends NodeImpl implements Entity {
    private String encoding = null;
    private String version = null;

    public EntityImpl() {
    }

    public EntityImpl(NodeImpl parentNode, byte[] data, int pos, int len) {
        super(parentNode, data, pos, len);
    }

    public EntityImpl(NodeImpl parentNode, boolean dirty) {
        super(parentNode, dirty);
    }

    public short getNodeType() {
        return Node.ENTITY_NODE;
    }

    /**
     * The public identifier associated with the entity, if specified. If the
     * public identifier was not specified, this is <code>null</code>.
     */
    public String getPublicId() {
        return null;
    }

    /**
     * The system identifier associated with the entity, if specified. If the
     * system identifier was not specified, this is <code>null</code>.
     */
    public String getSystemId() {
        return null;
    }

    /**
     * For unparsed entities, the name of the notation for the entity. For
     * parsed entities, this is <code>null</code>.
     */
    public String getNotationName() {
        return null;
    }

    // DOM Level 3 Stuff

    public String getEncoding() {
        checkLoaded();
        return encoding;
    }

    public void setEncoding(String encoding) {
        checkReadOnly();
        checkLoaded();
        this.encoding = encoding;
    }

    public String getVersion() {
        checkLoaded();
        return version;
    }

    public void setVersion(String version) {
        checkReadOnly();
        checkLoaded();
        this.version = version;
    }
}


