/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: NodeListImpl.java,v 1.6 2004/02/08 03:11:56 vgritsenko Exp $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import java.util.ArrayList;

/**
 * NodeListImpl
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 03:11:56 $
 */
public class NodeListImpl extends ArrayList implements NodeList {

    protected NodeImpl owner = null;

    public NodeListImpl(NodeImpl owner) {
        this.owner = owner;
    }

    /**
     * Returns the <code>index</code>th item in the collection. If
     * <code>index</code> is greater than or equal to the number of nodes in
     * the list, this returns <code>null</code>.
     * @param index Index into the collection.
     * @return The node at the <code>index</code>th position in the
     *   <code>NodeList</code>, or <code>null</code> if that is not a valid
     *   index.
     */
    public final Node item(int index) {
        try {
            return (Node) get(index);
        } catch (IndexOutOfBoundsException ioobe) {
            return null;
        }
    }

    /**
     * The number of nodes in the list. The range of valid child node indices is
     * 0 to <code>length-1</code> inclusive.
     */
    public final int getLength() {
        return size();
    }
}

