/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: TextImpl.java,v 1.4 2004/02/08 03:11:56 vgritsenko Exp $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;
import org.w3c.dom.Text;

/**
 * TextImpl
 *
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 03:11:56 $
 */
public class TextImpl extends CharacterDataImpl implements Text {

    public TextImpl() {
    }

    public TextImpl(NodeImpl parentNode, byte[] data, int pos, int len) {
        super(parentNode, data, pos, len);
    }

    public TextImpl(NodeImpl parentNode, boolean dirty) {
        super(parentNode, dirty);
    }

    public TextImpl(NodeImpl parentNode, String nodeValue) {
        super(parentNode, nodeValue);
    }

    public short getNodeType() {
        return Node.TEXT_NODE;
    }

    public String getNodeName() {
        return "#text";
    }

    /**
     * Breaks this <code>Text</code> node into two Text nodes at the specified
     * offset, keeping both in the tree as siblings. This node then only
     * contains all the content up to the <code>offset</code> point. And a new
     * <code>Text</code> node, which is inserted as the next sibling of  this
     * node, contains all the content at and after the <code>offset</code>
     * point.
     * @param offset The offset at which to split, starting from 0.
     * @return The new <code>Text</code> node.
     * @exception DOMException
     *   INDEX_SIZE_ERR: Raised if the specified offset is negative or greater
     *   than the number of characters in <code>data</code>.
     *   <br>NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
     */
    public final Text splitText(int offset) throws DOMException {
        String value = getNodeValue();
        checkReadOnly();
        try {
            String newValue = value.substring(0, offset);
            String oldValue = value.substring(offset + 1);
            Text text = getOwnerDocument().createTextNode(newValue);
            setNodeValue(oldValue);
            getParentNode().insertBefore(text, this);
            setDirty();
            return text;
        } catch (Exception e) {
            throw EX_INDEX_SIZE;
        }
    }
}

