/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: CompressionHandler.java,v 1.6 2004/02/08 03:50:14 vgritsenko Exp $
 */

package org.apache.xindice.xml.sax;

import org.apache.xindice.xml.SymbolTable;

/**
 * CompressionHandler is a SAX callback interface for reporting
 * positional information about Xindice compressed Documents.  All
 * of these methods will be called immediate before any SAX start
 * methods.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 03:50:14 $
 */
public interface CompressionHandler {
    static final String HANDLER = "CompressionHandler/1.0";

    /**
     * symbols reports the Symbol table that is being used for the
     * decompression.  This method should only be called when the
     * Symbol table changes in the stream.  For example, before and
     * after an imported Node is enountered that uses a diffferent
     * Symbol table.
     *
     * @param symbols The Symbol Table
     */
    void symbols(SymbolTable symbols);

    /**
     * dataBytes sets the byte array for the definitions to follow.
     * This method should only be called when the byte array object
     * changes in the stream.  For example, before and after an
     * imported Node is encountered that uses a different byte array.
     *
     * @param data The Data
     */
    void dataBytes(byte[] data);

    /**
     * dataLocation reports positional information for the Node to
     * follow.
     *
     * @param pos The offset into the data for this Node
     * @param len The length of this Node's definition
     */
    void dataLocation(int pos, int len);

    /**
     * symbolID reports the SymbolID for the Node to follow.  Because
     * Symbol IDs are specific to a Node type (Element, Entity, and
     * Attribute) this value needs to be stored until the type of Node
     * is reported.
     *
     * @param symbolID The Symbol ID
     */
    void symbolID(short symbolID);
}
