/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: CollectionTest.java,v 1.4 2004/02/08 03:56:47 vgritsenko Exp $
 */

package org.apache.xindice.core;

import org.apache.xindice.util.Configuration;
import org.apache.xindice.xml.TextWriter;
import org.apache.xindice.xml.dom.DOMParser;

import junit.framework.TestCase;
import org.w3c.dom.Document;

/**
 * Tests Xindice Core API (org.apache.xindice.core.Database,
 * org.apache.xindice.core.Collection)
 *
 * @author <a href="mailto:vgritsenko@apache.org">Vadim Gritsenko</a>
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 03:56:47 $
 */
public class CollectionTest extends TestCase {

	private Database db;
	private Collection collection;

	public CollectionTest(String name) {
        super(name);
	}

    public void setUp() throws Exception {
        String name = getClass().getName();
        db = new Database();
        db.setConfig(new Configuration(DOMParser.toDocument(DatabaseTest.DATABASE)));
        collection = db.createCollection(name, new Configuration(
                DOMParser.toDocument(
                        "<collection compressed=\"true\" name=\"" + name + "\" inline-metadata=\"true\">" +
                            "<filer class=\"org.apache.xindice.core.filer.BTreeFiler\" />" +
                        "</collection>"), false
        ));
    }

	public void tearDown() throws Exception {
		db.dropCollection(collection);
        db.close();
	}

    /**
     * Tests insertBinary, getBinary, remove
     */
	public void testBinary() throws Exception {
        byte[] in = new byte[256];
        for (int i = 0; i < in.length; i++) {
            in[i] = (byte) (Math.random() * 256);
        }

		collection.insertBinary("binary", in);
        byte[] out = collection.getBinary("binary");
		assertNotNull("Binary must be in there", out);
		assertEquals("The size of the found and saved binary should be the same", in.length, out.length);
		for (int i = 0; i < in.length; ++i) {
			assertEquals("The resources differ in byte " + i, in[i], out[i]);
		}

        collection.remove("binary");
        out = collection.getBinary("binary");
        assertNull("Binary should have been removed", out);
	}

    /**
     * Tests insertDocument, getDocument, remove
     */
	public void testDocument() throws Exception {
        Document in = collection.getConfig().getElement().getOwnerDocument();
        String inStr = TextWriter.toString(in);

		collection.insertDocument("document", in);
        Document out = collection.getDocument("document");
        assertNotNull("Document must be in there", out);
        String outStr = TextWriter.toString(out);
		assertEquals("Documents do not match", inStr, outStr);

        collection.remove("document");
        out = collection.getDocument("document");
        assertNull("Document should have been removed", out);
	}
}
