/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: TextWriterTest.java,v 1.1 2004/02/24 02:16:55 vgritsenko Exp $
 */

package org.apache.xindice.xml;

import org.apache.xindice.xml.dom.DOMParser;

import junit.framework.TestCase;
import org.w3c.dom.Node;
import org.w3c.dom.DocumentFragment;

import java.io.StringWriter;
import java.io.ByteArrayOutputStream;

/**
 * Tests TextWriter class
 * 
 * @version CVS $Revision: 1.1 $, $Date: 2004/02/24 02:16:55 $
 */
public class TextWriterTest extends TestCase {

    private static final String FRAGMENT =
            "<element attr1=\"value1\" attr2=\"value2\">\n" +
            "<!-- Comment Node -->\n" +
            "<empty-element />\n" +
            "<![CDATA[ CDATA Node ]]>\n" +
            "Text &lt;Node&gt; &amp; &apos;Escaped &quot;Text&quot;&apos;" +
            "</element>";

    private static final String XML =
            "<?xml version=\"1.0\"?>\n" + FRAGMENT;

    private Node dom;
    private TextWriter writer;

    public void setUp() throws Exception {
        dom = DOMParser.toDocument(XML);
        writer = new TextWriter(dom);
    }

    public void testToString() throws Exception {
        assertEquals(XML, writer.toString());
    }

    public void testWriter() throws Exception {
        StringWriter out = new StringWriter();
        writer.write(out);
        assertEquals(XML, out.toString());
    }

    public void testOutputStream() throws Exception {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        writer.write(out);
        assertEquals(XML, out.toString());
    }

    public void testWriter1() throws Exception {
        StringWriter out = new StringWriter();
        TextWriter.write(dom, out);
        assertEquals(XML, out.toString());
    }

    public void testOutputStream1() throws Exception {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        TextWriter.write(dom, out);
        assertEquals(XML, out.toString());
    }

    public void testFragment() throws Exception {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        DocumentFragment fragment = dom.getOwnerDocument().createDocumentFragment();
        fragment.appendChild(dom.getOwnerDocument().getDocumentElement());
        TextWriter.write(fragment, out);
        assertEquals(FRAGMENT, out.toString());
    }
}
